# IO.Swagger - the C# library for the Quote Management APIs

Ingram Micro quote management API for reading quotes.  *Production URL - https://api.ingrammicro.com:443/resellers/v5*

This C# SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 5.0
- SDK version: 1.0.0
- Build package: io.swagger.codegen.v3.generators.dotnet.CSharpClientCodegen
    For more information, please visit [https://developer.ingrammicro.com/contact](https://developer.ingrammicro.com/contact)

<a name="frameworks-supported"></a>
## Frameworks supported
- .NET 4.0 or later
- Windows Phone 7.1 (Mango)

<a name="dependencies"></a>
## Dependencies
- [RestSharp](https://www.nuget.org/packages/RestSharp) - 105.1.0 or later
- [Json.NET](https://www.nuget.org/packages/Newtonsoft.Json/) - 7.0.0 or later
- [JsonSubTypes](https://www.nuget.org/packages/JsonSubTypes/) - 1.2.0 or later

The DLLs included in the package may not be the latest version. We recommend using [NuGet](https://docs.nuget.org/consume/installing-nuget) to obtain the latest version of the packages:
```
Install-Package RestSharp
Install-Package Newtonsoft.Json
Install-Package JsonSubTypes
```

NOTE: RestSharp versions greater than 105.1.0 have a bug which causes file uploads to fail. See [RestSharp#742](https://github.com/restsharp/RestSharp/issues/742)

<a name="installation"></a>
## Installation
Run the following command to generate the DLL
- [Mac/Linux] `/bin/sh build.sh`
- [Windows] `build.bat`

Then include the DLL (under the `bin` folder) in the C# project, and use the namespaces:
```csharp
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;
```
<a name="packaging"></a>
## Packaging

A `.nuspec` is included with the project. You can follow the Nuget quickstart to [create](https://docs.microsoft.com/en-us/nuget/quickstart/create-and-publish-a-package#create-the-package) and [publish](https://docs.microsoft.com/en-us/nuget/quickstart/create-and-publish-a-package#publish-the-package) packages.

This `.nuspec` uses placeholders from the `.csproj`, so build the `.csproj` directly:

```
nuget pack -Build -OutputDirectory out IO.Swagger.csproj
```

Then, publish to a [local feed](https://docs.microsoft.com/en-us/nuget/hosting-packages/local-feeds) or [other host](https://docs.microsoft.com/en-us/nuget/hosting-packages/overview) and consume the new package via Nuget as usual.

<a name="getting-started"></a>
## Getting Started

```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class Example
    {
        public void main()
        {
            // Configure OAuth2 access token for authorization: application
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new QuotesApi();
            var quoteNumber = quoteNumber_example;  // string | Ingram Micro Quote Number
            var customerNumber = customerNumber_example;  // string | Your Ingram Micro unique customer number (default to 20-222222)
            var isoCountryCode = isoCountryCode_example;  // string |  (default to US)
            var thirdPartySource = thirdPartySource_example;  // string | Unique identifier used to identify the third party source accessing the services (optional)  (default to customer)

            try
            {
                // Get quote details
                QuoteDetails result = apiInstance.GetV5QuotesDetails(quoteNumber, customerNumber, isoCountryCode, thirdPartySource);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling QuotesApi.GetV5QuotesDetails: " + e.Message );
            }
        }
    }
}
```

<a name="documentation-for-api-endpoints"></a>
## Documentation for API Endpoints

All URIs are relative to *https://api.ingrammicro.com:443/sandbox/resellers/v5*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*QuotesApi* | [**GetV5QuotesDetails**](docs/QuotesApi.md#getv5quotesdetails) | **GET** /quotes/{quoteNumber} | Get quote details
*QuotesApi* | [**PostV5QuotesSearch**](docs/QuotesApi.md#postv5quotessearch) | **POST** /quotes/search | Search quotes

<a name="documentation-for-models"></a>
## Documentation for Models

 - [Model.QuoteDetails](docs/QuoteDetails.md)
 - [Model.QuoteDetailsQuoteDetailResponse](docs/QuoteDetailsQuoteDetailResponse.md)
 - [Model.QuoteDetailsQuoteDetailResponseResponsePreamble](docs/QuoteDetailsQuoteDetailResponseResponsePreamble.md)
 - [Model.QuoteDetailsQuoteDetailResponseRetrieveQuoteResponse](docs/QuoteDetailsQuoteDetailResponseRetrieveQuoteResponse.md)
 - [Model.QuoteDetailsQuoteDetailResponseRetrieveQuoteResponseAccountInfo](docs/QuoteDetailsQuoteDetailResponseRetrieveQuoteResponseAccountInfo.md)
 - [Model.QuoteDetailsQuoteDetailResponseRetrieveQuoteResponseContactInfo](docs/QuoteDetailsQuoteDetailResponseRetrieveQuoteResponseContactInfo.md)
 - [Model.QuoteDetailsQuoteDetailResponseRetrieveQuoteResponseEndUser](docs/QuoteDetailsQuoteDetailResponseRetrieveQuoteResponseEndUser.md)
 - [Model.QuoteDetailsQuoteDetailResponseRetrieveQuoteResponseVendorAttributes](docs/QuoteDetailsQuoteDetailResponseRetrieveQuoteResponseVendorAttributes.md)
 - [Model.QuoteDetailsRequest](docs/QuoteDetailsRequest.md)
 - [Model.QuoteDetailsRequestQuoteProductsRequest](docs/QuoteDetailsRequestQuoteProductsRequest.md)
 - [Model.QuoteDetailsRequestQuoteProductsRequestRequestpreamble](docs/QuoteDetailsRequestQuoteProductsRequestRequestpreamble.md)
 - [Model.QuoteDetailsRequestQuoteProductsRequestRetrieveQuoteProductsRequest](docs/QuoteDetailsRequestQuoteProductsRequestRetrieveQuoteProductsRequest.md)
 - [Model.QuoteListRequest](docs/QuoteListRequest.md)
 - [Model.QuoteListRequestQuoteSearchRequest](docs/QuoteListRequestQuoteSearchRequest.md)
 - [Model.QuoteListRequestQuoteSearchRequestRequestPreamble](docs/QuoteListRequestQuoteSearchRequestRequestPreamble.md)
 - [Model.QuoteListRequestQuoteSearchRequestRetrieveQuoteRequest](docs/QuoteListRequestQuoteSearchRequestRetrieveQuoteRequest.md)
 - [Model.QuoteListResponse](docs/QuoteListResponse.md)
 - [Model.QuoteListResponseQuoteSearchResponse](docs/QuoteListResponseQuoteSearchResponse.md)
 - [Model.QuoteListResponseQuoteSearchResponseQuoteList](docs/QuoteListResponseQuoteSearchResponseQuoteList.md)
 - [Model.QuoteListResponseQuoteSearchResponseResponsePreamble](docs/QuoteListResponseQuoteSearchResponseResponsePreamble.md)
 - [Model.QuoteProductList](docs/QuoteProductList.md)
 - [Model.QuoteProductListPrice](docs/QuoteProductListPrice.md)

<a name="documentation-for-authorization"></a>
## Documentation for Authorization

<a name="application"></a>
### application

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: 
  - : 

