/* 
 * Quote Management APIs
 *
 * Ingram Micro quote management API for reading quotes.  *Production URL - https://api.ingrammicro.com:443/resellers/v5*
 *
 * OpenAPI spec version: 5.0
 * 
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 */
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using RestSharp;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
        public interface IQuotesApi : IApiAccessor
    {
        #region Synchronous Operations
        /// <summary>
        /// Get quote details
        /// </summary>
        /// <remarks>
        /// The quote detail API will provide all quote details associated with the quote number provided in the call.  *NOTE: quoteNumber, isoCountryCode and customerNumber is mandatory.*
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="quoteNumber">Ingram Micro Quote Number</param>
        /// <param name="customerNumber">Your Ingram Micro unique customer number</param>
        /// <param name="isoCountryCode"></param>
        /// <param name="thirdPartySource">Unique identifier used to identify the third party source accessing the services (optional, default to customer)</param>
        /// <returns>QuoteDetails</returns>
        QuoteDetails GetV5QuotesDetails (string quoteNumber, string customerNumber, string isoCountryCode, string thirdPartySource = null);

        /// <summary>
        /// Get quote details
        /// </summary>
        /// <remarks>
        /// The quote detail API will provide all quote details associated with the quote number provided in the call.  *NOTE: quoteNumber, isoCountryCode and customerNumber is mandatory.*
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="quoteNumber">Ingram Micro Quote Number</param>
        /// <param name="customerNumber">Your Ingram Micro unique customer number</param>
        /// <param name="isoCountryCode"></param>
        /// <param name="thirdPartySource">Unique identifier used to identify the third party source accessing the services (optional, default to customer)</param>
        /// <returns>ApiResponse of QuoteDetails</returns>
        ApiResponse<QuoteDetails> GetV5QuotesDetailsWithHttpInfo (string quoteNumber, string customerNumber, string isoCountryCode, string thirdPartySource = null);
        /// <summary>
        /// Search quotes
        /// </summary>
        /// <remarks>
        /// The endpoint, by default, will retrieve quotes modified or created within the last 30 days Quotes older than 365 days are excluded by default. The date filters enable the retrieval of quotes older than 30 days and up to 365 days when using date range criteria.  The endpoint enables the retrieval and filtering of relevant quote list key criteria data such as Quote Number, Special Bid Numbers, End User Name, Quote Status, and Date Ranges from Ingram Micro&#x27;s CRM system. Only Active quotes are avaiable through the API. Draft and Closed quotes are excluded and are not accessable through the this API. 
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body"> (optional)</param>
        /// <returns>QuoteListResponse</returns>
        QuoteListResponse PostV5QuotesSearch (QuoteListRequest body = null);

        /// <summary>
        /// Search quotes
        /// </summary>
        /// <remarks>
        /// The endpoint, by default, will retrieve quotes modified or created within the last 30 days Quotes older than 365 days are excluded by default. The date filters enable the retrieval of quotes older than 30 days and up to 365 days when using date range criteria.  The endpoint enables the retrieval and filtering of relevant quote list key criteria data such as Quote Number, Special Bid Numbers, End User Name, Quote Status, and Date Ranges from Ingram Micro&#x27;s CRM system. Only Active quotes are avaiable through the API. Draft and Closed quotes are excluded and are not accessable through the this API. 
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body"> (optional)</param>
        /// <returns>ApiResponse of QuoteListResponse</returns>
        ApiResponse<QuoteListResponse> PostV5QuotesSearchWithHttpInfo (QuoteListRequest body = null);
        #endregion Synchronous Operations
        #region Asynchronous Operations
        /// <summary>
        /// Get quote details
        /// </summary>
        /// <remarks>
        /// The quote detail API will provide all quote details associated with the quote number provided in the call.  *NOTE: quoteNumber, isoCountryCode and customerNumber is mandatory.*
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="quoteNumber">Ingram Micro Quote Number</param>
        /// <param name="customerNumber">Your Ingram Micro unique customer number</param>
        /// <param name="isoCountryCode"></param>
        /// <param name="thirdPartySource">Unique identifier used to identify the third party source accessing the services (optional, default to customer)</param>
        /// <returns>Task of QuoteDetails</returns>
        System.Threading.Tasks.Task<QuoteDetails> GetV5QuotesDetailsAsync (string quoteNumber, string customerNumber, string isoCountryCode, string thirdPartySource = null);

        /// <summary>
        /// Get quote details
        /// </summary>
        /// <remarks>
        /// The quote detail API will provide all quote details associated with the quote number provided in the call.  *NOTE: quoteNumber, isoCountryCode and customerNumber is mandatory.*
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="quoteNumber">Ingram Micro Quote Number</param>
        /// <param name="customerNumber">Your Ingram Micro unique customer number</param>
        /// <param name="isoCountryCode"></param>
        /// <param name="thirdPartySource">Unique identifier used to identify the third party source accessing the services (optional, default to customer)</param>
        /// <returns>Task of ApiResponse (QuoteDetails)</returns>
        System.Threading.Tasks.Task<ApiResponse<QuoteDetails>> GetV5QuotesDetailsAsyncWithHttpInfo (string quoteNumber, string customerNumber, string isoCountryCode, string thirdPartySource = null);
        /// <summary>
        /// Search quotes
        /// </summary>
        /// <remarks>
        /// The endpoint, by default, will retrieve quotes modified or created within the last 30 days Quotes older than 365 days are excluded by default. The date filters enable the retrieval of quotes older than 30 days and up to 365 days when using date range criteria.  The endpoint enables the retrieval and filtering of relevant quote list key criteria data such as Quote Number, Special Bid Numbers, End User Name, Quote Status, and Date Ranges from Ingram Micro&#x27;s CRM system. Only Active quotes are avaiable through the API. Draft and Closed quotes are excluded and are not accessable through the this API. 
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body"> (optional)</param>
        /// <returns>Task of QuoteListResponse</returns>
        System.Threading.Tasks.Task<QuoteListResponse> PostV5QuotesSearchAsync (QuoteListRequest body = null);

        /// <summary>
        /// Search quotes
        /// </summary>
        /// <remarks>
        /// The endpoint, by default, will retrieve quotes modified or created within the last 30 days Quotes older than 365 days are excluded by default. The date filters enable the retrieval of quotes older than 30 days and up to 365 days when using date range criteria.  The endpoint enables the retrieval and filtering of relevant quote list key criteria data such as Quote Number, Special Bid Numbers, End User Name, Quote Status, and Date Ranges from Ingram Micro&#x27;s CRM system. Only Active quotes are avaiable through the API. Draft and Closed quotes are excluded and are not accessable through the this API. 
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body"> (optional)</param>
        /// <returns>Task of ApiResponse (QuoteListResponse)</returns>
        System.Threading.Tasks.Task<ApiResponse<QuoteListResponse>> PostV5QuotesSearchAsyncWithHttpInfo (QuoteListRequest body = null);
        #endregion Asynchronous Operations
    }

    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
        public partial class QuotesApi : IQuotesApi
    {
        private IO.Swagger.Client.ExceptionFactory _exceptionFactory = (name, response) => null;

        /// <summary>
        /// Initializes a new instance of the <see cref="QuotesApi"/> class.
        /// </summary>
        /// <returns></returns>
        public QuotesApi(String basePath)
        {
            this.Configuration = new IO.Swagger.Client.Configuration { BasePath = basePath };

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="QuotesApi"/> class
        /// </summary>
        /// <returns></returns>
        public QuotesApi()
        {
            this.Configuration = IO.Swagger.Client.Configuration.Default;

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="QuotesApi"/> class
        /// using Configuration object
        /// </summary>
        /// <param name="configuration">An instance of Configuration</param>
        /// <returns></returns>
        public QuotesApi(IO.Swagger.Client.Configuration configuration = null)
        {
            if (configuration == null) // use the default one in Configuration
                this.Configuration = IO.Swagger.Client.Configuration.Default;
            else
                this.Configuration = configuration;

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;
        }

        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        public String GetBasePath()
        {
            return this.Configuration.ApiClient.RestClient.BaseUrl.ToString();
        }

        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        [Obsolete("SetBasePath is deprecated, please do 'Configuration.ApiClient = new ApiClient(\"http://new-path\")' instead.")]
        public void SetBasePath(String basePath)
        {
            // do nothing
        }

        /// <summary>
        /// Gets or sets the configuration object
        /// </summary>
        /// <value>An instance of the Configuration</value>
        public IO.Swagger.Client.Configuration Configuration {get; set;}

        /// <summary>
        /// Provides a factory method hook for the creation of exceptions.
        /// </summary>
        public IO.Swagger.Client.ExceptionFactory ExceptionFactory
        {
            get
            {
                if (_exceptionFactory != null && _exceptionFactory.GetInvocationList().Length > 1)
                {
                    throw new InvalidOperationException("Multicast delegate for ExceptionFactory is unsupported.");
                }
                return _exceptionFactory;
            }
            set { _exceptionFactory = value; }
        }

        /// <summary>
        /// Gets the default header.
        /// </summary>
        /// <returns>Dictionary of HTTP header</returns>
        [Obsolete("DefaultHeader is deprecated, please use Configuration.DefaultHeader instead.")]
        public IDictionary<String, String> DefaultHeader()
        {
            return new ReadOnlyDictionary<string, string>(this.Configuration.DefaultHeader);
        }

        /// <summary>
        /// Add default header.
        /// </summary>
        /// <param name="key">Header field name.</param>
        /// <param name="value">Header field value.</param>
        /// <returns></returns>
        [Obsolete("AddDefaultHeader is deprecated, please use Configuration.AddDefaultHeader instead.")]
        public void AddDefaultHeader(string key, string value)
        {
            this.Configuration.AddDefaultHeader(key, value);
        }

        /// <summary>
        /// Get quote details The quote detail API will provide all quote details associated with the quote number provided in the call.  *NOTE: quoteNumber, isoCountryCode and customerNumber is mandatory.*
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="quoteNumber">Ingram Micro Quote Number</param>
        /// <param name="customerNumber">Your Ingram Micro unique customer number</param>
        /// <param name="isoCountryCode"></param>
        /// <param name="thirdPartySource">Unique identifier used to identify the third party source accessing the services (optional, default to customer)</param>
        /// <returns>QuoteDetails</returns>
        public QuoteDetails GetV5QuotesDetails (string quoteNumber, string customerNumber, string isoCountryCode, string thirdPartySource = null)
        {
             ApiResponse<QuoteDetails> localVarResponse = GetV5QuotesDetailsWithHttpInfo(quoteNumber, customerNumber, isoCountryCode, thirdPartySource);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Get quote details The quote detail API will provide all quote details associated with the quote number provided in the call.  *NOTE: quoteNumber, isoCountryCode and customerNumber is mandatory.*
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="quoteNumber">Ingram Micro Quote Number</param>
        /// <param name="customerNumber">Your Ingram Micro unique customer number</param>
        /// <param name="isoCountryCode"></param>
        /// <param name="thirdPartySource">Unique identifier used to identify the third party source accessing the services (optional, default to customer)</param>
        /// <returns>ApiResponse of QuoteDetails</returns>
        public ApiResponse< QuoteDetails > GetV5QuotesDetailsWithHttpInfo (string quoteNumber, string customerNumber, string isoCountryCode, string thirdPartySource = null)
        {
            // verify the required parameter 'quoteNumber' is set
            if (quoteNumber == null)
                throw new ApiException(400, "Missing required parameter 'quoteNumber' when calling QuotesApi->GetV5QuotesDetails");
            // verify the required parameter 'customerNumber' is set
            if (customerNumber == null)
                throw new ApiException(400, "Missing required parameter 'customerNumber' when calling QuotesApi->GetV5QuotesDetails");
            // verify the required parameter 'isoCountryCode' is set
            if (isoCountryCode == null)
                throw new ApiException(400, "Missing required parameter 'isoCountryCode' when calling QuotesApi->GetV5QuotesDetails");

            var localVarPath = "/quotes/{quoteNumber}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (quoteNumber != null) localVarPathParams.Add("quoteNumber", this.Configuration.ApiClient.ParameterToString(quoteNumber)); // path parameter
            if (customerNumber != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "customerNumber", customerNumber)); // query parameter
            if (isoCountryCode != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "isoCountryCode", isoCountryCode)); // query parameter
            if (thirdPartySource != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "thirdPartySource", thirdPartySource)); // query parameter
            // authentication (application) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetV5QuotesDetails", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<QuoteDetails>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => string.Join(",", x.Value)),
                (QuoteDetails) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(QuoteDetails)));
        }

        /// <summary>
        /// Get quote details The quote detail API will provide all quote details associated with the quote number provided in the call.  *NOTE: quoteNumber, isoCountryCode and customerNumber is mandatory.*
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="quoteNumber">Ingram Micro Quote Number</param>
        /// <param name="customerNumber">Your Ingram Micro unique customer number</param>
        /// <param name="isoCountryCode"></param>
        /// <param name="thirdPartySource">Unique identifier used to identify the third party source accessing the services (optional, default to customer)</param>
        /// <returns>Task of QuoteDetails</returns>
        public async System.Threading.Tasks.Task<QuoteDetails> GetV5QuotesDetailsAsync (string quoteNumber, string customerNumber, string isoCountryCode, string thirdPartySource = null)
        {
             ApiResponse<QuoteDetails> localVarResponse = await GetV5QuotesDetailsAsyncWithHttpInfo(quoteNumber, customerNumber, isoCountryCode, thirdPartySource);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Get quote details The quote detail API will provide all quote details associated with the quote number provided in the call.  *NOTE: quoteNumber, isoCountryCode and customerNumber is mandatory.*
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="quoteNumber">Ingram Micro Quote Number</param>
        /// <param name="customerNumber">Your Ingram Micro unique customer number</param>
        /// <param name="isoCountryCode"></param>
        /// <param name="thirdPartySource">Unique identifier used to identify the third party source accessing the services (optional, default to customer)</param>
        /// <returns>Task of ApiResponse (QuoteDetails)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<QuoteDetails>> GetV5QuotesDetailsAsyncWithHttpInfo (string quoteNumber, string customerNumber, string isoCountryCode, string thirdPartySource = null)
        {
            // verify the required parameter 'quoteNumber' is set
            if (quoteNumber == null)
                throw new ApiException(400, "Missing required parameter 'quoteNumber' when calling QuotesApi->GetV5QuotesDetails");
            // verify the required parameter 'customerNumber' is set
            if (customerNumber == null)
                throw new ApiException(400, "Missing required parameter 'customerNumber' when calling QuotesApi->GetV5QuotesDetails");
            // verify the required parameter 'isoCountryCode' is set
            if (isoCountryCode == null)
                throw new ApiException(400, "Missing required parameter 'isoCountryCode' when calling QuotesApi->GetV5QuotesDetails");

            var localVarPath = "/quotes/{quoteNumber}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (quoteNumber != null) localVarPathParams.Add("quoteNumber", this.Configuration.ApiClient.ParameterToString(quoteNumber)); // path parameter
            if (customerNumber != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "customerNumber", customerNumber)); // query parameter
            if (isoCountryCode != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "isoCountryCode", isoCountryCode)); // query parameter
            if (thirdPartySource != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "thirdPartySource", thirdPartySource)); // query parameter
            // authentication (application) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetV5QuotesDetails", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<QuoteDetails>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => string.Join(",", x.Value)),
                (QuoteDetails) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(QuoteDetails)));
        }

        /// <summary>
        /// Search quotes The endpoint, by default, will retrieve quotes modified or created within the last 30 days Quotes older than 365 days are excluded by default. The date filters enable the retrieval of quotes older than 30 days and up to 365 days when using date range criteria.  The endpoint enables the retrieval and filtering of relevant quote list key criteria data such as Quote Number, Special Bid Numbers, End User Name, Quote Status, and Date Ranges from Ingram Micro&#x27;s CRM system. Only Active quotes are avaiable through the API. Draft and Closed quotes are excluded and are not accessable through the this API. 
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body"> (optional)</param>
        /// <returns>QuoteListResponse</returns>
        public QuoteListResponse PostV5QuotesSearch (QuoteListRequest body = null)
        {
             ApiResponse<QuoteListResponse> localVarResponse = PostV5QuotesSearchWithHttpInfo(body);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Search quotes The endpoint, by default, will retrieve quotes modified or created within the last 30 days Quotes older than 365 days are excluded by default. The date filters enable the retrieval of quotes older than 30 days and up to 365 days when using date range criteria.  The endpoint enables the retrieval and filtering of relevant quote list key criteria data such as Quote Number, Special Bid Numbers, End User Name, Quote Status, and Date Ranges from Ingram Micro&#x27;s CRM system. Only Active quotes are avaiable through the API. Draft and Closed quotes are excluded and are not accessable through the this API. 
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body"> (optional)</param>
        /// <returns>ApiResponse of QuoteListResponse</returns>
        public ApiResponse< QuoteListResponse > PostV5QuotesSearchWithHttpInfo (QuoteListRequest body = null)
        {

            var localVarPath = "/quotes/search";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (body != null && body.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(body); // http body (model) parameter
            }
            else
            {
                localVarPostBody = body; // byte array
            }
            // authentication (application) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PostV5QuotesSearch", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<QuoteListResponse>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => string.Join(",", x.Value)),
                (QuoteListResponse) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(QuoteListResponse)));
        }

        /// <summary>
        /// Search quotes The endpoint, by default, will retrieve quotes modified or created within the last 30 days Quotes older than 365 days are excluded by default. The date filters enable the retrieval of quotes older than 30 days and up to 365 days when using date range criteria.  The endpoint enables the retrieval and filtering of relevant quote list key criteria data such as Quote Number, Special Bid Numbers, End User Name, Quote Status, and Date Ranges from Ingram Micro&#x27;s CRM system. Only Active quotes are avaiable through the API. Draft and Closed quotes are excluded and are not accessable through the this API. 
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body"> (optional)</param>
        /// <returns>Task of QuoteListResponse</returns>
        public async System.Threading.Tasks.Task<QuoteListResponse> PostV5QuotesSearchAsync (QuoteListRequest body = null)
        {
             ApiResponse<QuoteListResponse> localVarResponse = await PostV5QuotesSearchAsyncWithHttpInfo(body);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Search quotes The endpoint, by default, will retrieve quotes modified or created within the last 30 days Quotes older than 365 days are excluded by default. The date filters enable the retrieval of quotes older than 30 days and up to 365 days when using date range criteria.  The endpoint enables the retrieval and filtering of relevant quote list key criteria data such as Quote Number, Special Bid Numbers, End User Name, Quote Status, and Date Ranges from Ingram Micro&#x27;s CRM system. Only Active quotes are avaiable through the API. Draft and Closed quotes are excluded and are not accessable through the this API. 
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body"> (optional)</param>
        /// <returns>Task of ApiResponse (QuoteListResponse)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<QuoteListResponse>> PostV5QuotesSearchAsyncWithHttpInfo (QuoteListRequest body = null)
        {

            var localVarPath = "/quotes/search";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (body != null && body.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(body); // http body (model) parameter
            }
            else
            {
                localVarPostBody = body; // byte array
            }
            // authentication (application) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PostV5QuotesSearch", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<QuoteListResponse>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => string.Join(",", x.Value)),
                (QuoteListResponse) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(QuoteListResponse)));
        }

    }
}
